@@ -24,26 +24,24 @@ static int init_vsl(int argc, char **argv)
 
 	if (m_vd != NULL)
 	{
-		VSM_ReOpen(m_vd, 0);
-	}
-	else
-	{
-		m_vd = VSM_New();
-		VSL_Setup(m_vd);
+		VSL_Delete(m_vd);
+		VSM_Close(m_vd);
 	}
 
+	vd = VSM_New();
+	VSL_Setup(vd);
 
 	while ((c = getopt(argc, argv, VSL_ARGS)) != -1)
 	{
-		VSL_Arg(m_vd, c, optarg);
+		VSL_Arg(vd, c, optarg);
 	}
 
-	if (VSL_Open(m_vd, 1))
+	if (VSL_Open(vd, 1))
 	{
 		return -1;
 	}
 
-	VSL_NonBlocking(m_vd, 1);
+	m_vd = vd;
 
 	return 0;
 }
